@@ -58,23 +58,23 @@ AnjutaPluginDescription* anjuta_plugin_description_new (const gchar *filename,
 AnjutaPluginDescription* anjuta_plugin_description_new_from_string (gchar *data,
 																	GError **error);
 
-gchar* anjuta_plugin_description_to_string (AnjutaPluginDescription *pf);
+gchar* anjuta_plugin_description_to_string (AnjutaPluginDescription *df);
 
-void anjuta_plugin_description_free (AnjutaPluginDescription *pf);
+void anjuta_plugin_description_free (AnjutaPluginDescription *df);
 
-void anjuta_plugin_description_foreach_section (AnjutaPluginDescription *pf,
+void anjuta_plugin_description_foreach_section (AnjutaPluginDescription *df,
 												AnjutaPluginDescriptionSectionFunc func,
 												gpointer user_data);
 
 void anjuta_plugin_description_foreach_key (AnjutaPluginDescription *df,
-											const gchar *section,
+											const gchar *section_name,
 											gboolean include_localized,
 											AnjutaPluginDescriptionLineFunc func,
 											gpointer user_data);
 
 /* Gets the raw text of the key, unescaped */
 gboolean anjuta_plugin_description_get_raw (AnjutaPluginDescription *df,
-										    const gchar *section,
+										    const gchar *section_name,
 											const gchar *keyname,
 											const gchar *locale,
 											gchar **val);
