@@ -238,7 +238,7 @@ anjuta_profile_class_init (AnjutaProfileClass *klass)
 	                                 PROP_SYNC_URI,
 	                                 g_param_spec_string ("sync-uri",
 											  _("Synchronization URI"),
-											  _("URI to sync the proflie xml"),
+											  _("URI to sync the profile xml"),
 											  NULL,
 											  G_PARAM_READABLE |
 											  G_PARAM_WRITABLE));
@@ -467,8 +467,8 @@ anjuta_profile_select_plugins (AnjutaProfile *profile,
 		{
 			AnjutaPluginDescription* d;
 			d = anjuta_plugin_manager_select (priv->plugin_manager,
-											  "Select a plugin",
-											  "Please select a plugin from the list",
+											  _("Select a plugin"),
+											  _("Please select a plugin from the list"),
 											  descs);
 			if (d)
 				selected_plugins = g_list_prepend (selected_plugins, d);
@@ -578,7 +578,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 	{
 		g_set_error (error, ANJUTA_PROFILE_ERROR,
 					 ANJUTA_PROFILE_ERROR_URI_READ_FAILED,
-					 _("Failed to read '%s': XML parse error."
+					 _("Failed to read '%s': XML parse error. "
 					   "Invalid or corrupted anjuta plugins profile."),
 					 profile_xml_uri);
 		xmlFreeDoc(xml_doc);
@@ -729,7 +729,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 		
 		g_set_error (error, ANJUTA_PROFILE_ERROR,
 					 ANJUTA_PROFILE_ERROR_URI_READ_FAILED,
-					 _("Failed to read '%s': XML parse error."
+					 _("Failed to read '%s': XML parse error. "
 					   "Invalid or corrupted anjuta plugins profile."),
 					 profile_xml_uri);
 		xmlFreeDoc(xml_doc);
@@ -751,6 +751,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 		node_url = not_found_urls;
 		while (node_name)
 		{
+			/* <Pluginname>: Install it from <some location on the web> */
 			g_string_append_printf (mesg, _("%s: Install it from '%s'\n"),
 											(char *)node_name->data,
 											(char*)node_url->data);
@@ -843,7 +844,7 @@ anjuta_profile_to_xml (AnjutaProfile *profile)
 				continue;
 			}
 			g_free (user_activatable);
-			
+			/* Do not use the _locale_ version because it's not in UI */
 			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 												  "Name", &name);
 			DEBUG_PRINT("Saving plugin: %s", name);
@@ -870,10 +871,11 @@ anjuta_profile_to_xml (AnjutaProfile *profile)
 		else
 		{
 			gchar* name;
+			/* Do not use the _locale_ version because it's debugging */
 			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 												  "Name", &name);
-			DEBUG_PRINT("excluding plugin: %s", name);
-			g_free(name);
+			DEBUG_PRINT ("excluding plugin: %s", name);
+			g_free (name);
 		}
 		node = g_list_next (node);
 	}
