@@ -93,7 +93,6 @@ void on_force_hilite_activate (GtkWidget *menuitem, gpointer user_data);
 void on_indent1_activate (GtkAction *action, gpointer user_data);
 
 void on_format_indent_style_clicked (GtkAction *action, gpointer user_data);
-void on_swap_activate (GtkAction *action, gpointer user_data);
 
 void on_editor_add_view_activate (GtkAction *action, gpointer user_data);
 void on_editor_remove_view_activate (GtkAction *action, gpointer user_data);
@@ -101,4 +100,7 @@ void on_editor_remove_view_activate (GtkAction *action, gpointer user_data);
 void on_show_search (GtkAction *action, gpointer user_data);
 void on_repeat_quicksearch (GtkAction *action, gpointer user_data);
 
+void on_next_document (GtkAction *action, gpointer user_data);
+void on_previous_document (GtkAction *action, gpointer user_data);
+
 #endif
