@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
  
 #include <libanjuta/anjuta-launcher.h>
@@ -27,11 +27,14 @@
 static void patch_level_changed (GtkAdjustment *adj);
 
 static void on_ok_clicked (GtkButton *button, PatchPlugin* p_plugin);
-static void on_cancel_clicked (GtkButton *button, GtkDialog* dialog);
+static void on_cancel_clicked (GtkButton *button, PatchPlugin* plugin);
 
 static void on_msg_arrived (AnjutaLauncher *launcher,
 							AnjutaLauncherOutputType output_type,
 							const gchar* line, gpointer data);
+static void on_msg_buffer (IAnjutaMessageView *view, const gchar *line,
+					  PatchPlugin *plugin);
+
 static void on_patch_terminated (AnjutaLauncher *launcher,
 								 gint child_pid, gint status, gulong time_taken,
 								 gpointer data);
@@ -46,38 +49,73 @@ patch_level_changed (GtkAdjustment *adj)
 	patch_level = (gint) adj->value;
 }
 
+static gchar* get_project_uri(PatchPlugin *plugin)
+{
+	GValue value = {0, };
+	gchar* uri;
+	GError* err = NULL;
+	anjuta_shell_get_value (ANJUTA_PLUGIN (plugin)->shell,
+													"project_root_uri",
+													&value,
+													&err);
+	if (err)
+	{
+		g_error_free(err);
+		return NULL;
+	}
+	uri = g_value_dup_string (&value);
+	return uri;
+}
+  
 void
 patch_show_gui (PatchPlugin *plugin)
 {
 	GtkWidget* table;
-	GtkWidget* patch_button;
-	GtkWidget* cancel_button;
 	GtkWidget* scale;
 	GtkAdjustment* adj;
+  gchar* uri = get_project_uri(plugin);
+  GtkFileFilter* filter;
 	
 	GladeXML* gxml;
 	
 	gxml = glade_xml_new(GLADE_FILE, "patch_dialog", NULL);
 	
 	plugin->dialog = glade_xml_get_widget(gxml, "patch_dialog");
+	plugin->output_label = glade_xml_get_widget(gxml, "output");
 	
 	table = glade_xml_get_widget(gxml, "patch_table");
 
-#if GTK_MINOR_VERSION >= 6
 	plugin->file_chooser = gtk_file_chooser_button_new(_("File/Directory to patch"),
-											   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-	plugin->patch_chooser = gtk_file_chooser_button_new(_("Patch file"),
-											   GTK_FILE_CHOOSER_ACTION_OPEN);
-
-	gtk_file_chooser_button_set_width_chars(GTK_FILE_CHOOSER_BUTTON(plugin->file_chooser),
-											30);
-	gtk_file_chooser_button_set_width_chars(GTK_FILE_CHOOSER_BUTTON(plugin->patch_chooser),
-									30);
-#else
-	plugin->file_chooser = gnome_file_entry_new("patch_dir", _("File/Directory to patch"));
-	plugin->patch_chooser = gnome_file_entry_new("patch_file", _("Patch file"));
-#endif
+																										 GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 	
+	plugin->patch_chooser = gtk_file_chooser_button_new(_("Patch file"),
+																											GTK_FILE_CHOOSER_ACTION_OPEN);
+	
+	if (uri)
+	{
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER(plugin->file_chooser),
+																						 uri);
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER(plugin->patch_chooser),
+																						 uri);
+	}
+	g_free(uri);
+	
+	gtk_file_chooser_button_set_width_chars(GTK_FILE_CHOOSER_BUTTON(plugin->file_chooser),
+																					30);
+	gtk_file_chooser_button_set_width_chars(GTK_FILE_CHOOSER_BUTTON(plugin->patch_chooser),
+																					30);
+	
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pattern (filter, "*.diff");
+	gtk_file_filter_add_pattern (filter, "*.patch");
+	gtk_file_filter_set_name (filter, _("Patches"));  
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (plugin->patch_chooser),
+															 filter);
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pattern (filter, "*");
+	gtk_file_filter_set_name (filter, _("All files"));  
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (plugin->patch_chooser),
+															 filter);
 	
 	gtk_table_attach_defaults(GTK_TABLE(table), plugin->file_chooser, 1, 2, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), plugin->patch_chooser, 1, 2, 1, 2);
@@ -87,14 +125,16 @@ patch_show_gui (PatchPlugin *plugin)
 	g_signal_connect (G_OBJECT(adj), "value_changed",
 			    GTK_SIGNAL_FUNC (patch_level_changed), NULL);
 		
-	patch_button = glade_xml_get_widget(gxml, "patch_button");
-	cancel_button = glade_xml_get_widget(gxml, "cancel_button");
+	plugin->patch_button = glade_xml_get_widget(gxml, "patch_button");
+	plugin->cancel_button = glade_xml_get_widget(gxml, "cancel_button");
+	plugin->dry_run_check = glade_xml_get_widget(gxml, "dryrun");
 	
-	g_signal_connect (G_OBJECT (patch_button), "clicked", 
+	g_signal_connect (G_OBJECT (plugin->patch_button), "clicked", 
 			G_CALLBACK(on_ok_clicked), plugin);
-	g_signal_connect (G_OBJECT (cancel_button), "clicked", 
-			G_CALLBACK(on_cancel_clicked), plugin->dialog);
-
+	g_signal_connect (G_OBJECT (plugin->cancel_button), "clicked", 
+			G_CALLBACK(on_cancel_clicked), plugin);
+	
+	plugin->executing = FALSE;
 	gtk_widget_show_all (plugin->dialog);
 }
 
@@ -121,25 +161,26 @@ on_ok_clicked (GtkButton *button, PatchPlugin* p_plugin)
 	
 	ianjuta_message_manager_set_current_view (mesg_manager, p_plugin->mesg_view, NULL);	
 
-#if GTK_MINOR_VERSION >= 6
+	g_signal_connect (G_OBJECT (p_plugin->mesg_view), "buffer-flushed",
+						  G_CALLBACK (on_msg_buffer), p_plugin);
+
 	directory = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(p_plugin->file_chooser));
-	patch_file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(p_plugin->patch_chooser));
-#else
-	directory = gnome_file_entry_get_full_path(
-								GNOME_FILE_ENTRY(p_plugin->file_chooser), FALSE);
-	patch_file = gnome_file_entry_get_full_path(
-								GNOME_FILE_ENTRY(p_plugin->patch_chooser), FALSE);
-#endif								
+	patch_file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(p_plugin->patch_chooser));						
 	
 	if (!g_file_test (directory, G_FILE_TEST_IS_DIR))
 	{
 		g_string_free (command, TRUE);
-		gnome_ok_dialog (_("Please select the directory where the patch should be applied"));
+		anjuta_util_dialog_error(GTK_WINDOW(p_plugin->dialog), 
+			_("Please select the directory where the patch should be applied"));
 		return;
 	}
 	
-	g_string_sprintf (command, "patch -d %s -p %d -f -i %s",
-			  directory, patch_level, patch_file);
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p_plugin->dry_run_check)))
+		g_string_sprintf (command, "patch --dry-run -d %s -p %d -f -i %s",
+				  directory, patch_level, patch_file);
+	else
+		g_string_sprintf (command, "patch -d %s -p %d -f -i %s",
+				  directory, patch_level, patch_file);
 	
 	message = g_strdup_printf (_("Patching %s using %s\n"), 
 			  directory, patch_file);
@@ -156,22 +197,28 @@ on_ok_clicked (GtkButton *button, PatchPlugin* p_plugin)
 					  G_CALLBACK (on_patch_terminated), p_plugin);
 	
 	if (!anjuta_launcher_is_busy (p_plugin->launcher))
+	{
 		anjuta_launcher_execute (p_plugin->launcher, command->str,
 								 (AnjutaLauncherOutputCallback)on_msg_arrived, p_plugin);
+		p_plugin->executing = TRUE;
+		gtk_label_set_text(GTK_LABEL(p_plugin->output_label), _("Patching..."));
+		gtk_widget_set_sensitive(p_plugin->patch_button, FALSE);
+	}
 	else
-		gnome_ok_dialog (
-			_("There are unfinished jobs, please wait until they are finished"));
+		anjuta_util_dialog_error(GTK_WINDOW(p_plugin->dialog),
+			_("There are unfinished jobs, please wait until they are finished."));
 	g_string_free(command, TRUE);
-	
-	gtk_widget_hide (p_plugin->dialog);
-	gtk_widget_destroy (p_plugin->dialog);
 }
 
 static void 
-on_cancel_clicked (GtkButton *button, GtkDialog* dialog)
+on_cancel_clicked (GtkButton *button, PatchPlugin* plugin)
 {
-	gtk_widget_hide (GTK_WIDGET(dialog));
-	gtk_widget_destroy (GTK_WIDGET(dialog));
+	if (plugin->executing == TRUE)
+	{
+		anjuta_launcher_reset(plugin->launcher);
+	}
+	gtk_widget_hide (GTK_WIDGET(plugin->dialog));
+	gtk_widget_destroy (GTK_WIDGET(plugin->dialog));
 }
 
 static void 
@@ -181,10 +228,8 @@ on_msg_arrived (AnjutaLauncher *launcher,
 {	
 	g_return_if_fail (line != NULL);	
 	
-	PatchPlugin* p_plugin = (PatchPlugin*)data;
-	ianjuta_message_view_append (p_plugin->mesg_view,
-								 IANJUTA_MESSAGE_VIEW_TYPE_NORMAL,
-								 line, "", NULL);
+	PatchPlugin* p_plugin = ANJUTA_PLUGIN_PATCH (data);
+	ianjuta_message_view_buffer_append (p_plugin->mesg_view, line, NULL);
 }
 
 static void 
@@ -194,7 +239,7 @@ on_patch_terminated (AnjutaLauncher *launcher,
 {
 	g_return_if_fail (launcher != NULL);
 	
-	PatchPlugin* plugin = (PatchPlugin*)data;
+	PatchPlugin* plugin = ANJUTA_PLUGIN_PATCH (data);
 	
 	g_signal_handlers_disconnect_by_func (G_OBJECT (launcher),
 										  G_CALLBACK (on_patch_terminated),
@@ -202,17 +247,30 @@ on_patch_terminated (AnjutaLauncher *launcher,
 
 	if (status != 0)
 	{
-		ianjuta_message_view_append (plugin->mesg_view,
-								 IANJUTA_MESSAGE_VIEW_TYPE_ERROR,
-								 _("Patch failed.\nPlease review the failure messages.\n"
-			"Examine and remove any rejected files.\n"), "", NULL);		
+		gtk_label_set_text(GTK_LABEL(plugin->output_label), 
+			_("Patch failed.\nPlease review the failure messages.\n"
+			"Examine and remove any rejected files.\n"));
+		gtk_widget_set_sensitive(plugin->patch_button, TRUE);	
 	}
 	else
 	{
-		ianjuta_message_view_append (plugin->mesg_view,
-								 IANJUTA_MESSAGE_VIEW_TYPE_NORMAL,
-								 _("Patch successful.\n"), "", NULL);
+		gtk_label_set_text(GTK_LABEL(plugin->output_label), _("Patching complete"));
+		if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->dry_run_check)))
+		{
+			gtk_widget_hide (plugin->dialog);
+			gtk_widget_destroy (plugin->dialog);
+		}
+		else
+			gtk_widget_set_sensitive(plugin->patch_button, TRUE);
 	}
 
+	plugin->executing = FALSE;
 	plugin->mesg_view = NULL;
 }
+
+static void
+on_msg_buffer (IAnjutaMessageView *view, const gchar *line,
+					  PatchPlugin *plugin)
+{
+	ianjuta_message_view_append (view, IANJUTA_MESSAGE_VIEW_TYPE_NORMAL, line, "", NULL);
+}
