@@ -36,8 +36,6 @@
 #include <libanjuta/interfaces/ianjuta-bookmark.h>
 #include <libanjuta/interfaces/ianjuta-indicable.h>
 
-#include <libegg/menu/egg-entry-action.h>
-
 #include "search-replace_backend.h"
 #include "search-replace.h"
 #include "search_preferences.h"
@@ -230,6 +228,7 @@ static GladeWidget glade_widgets[] = {
 static void
 write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se, MatchInfo *mi);
 static gboolean on_message_clicked (GObject* object, gchar* message, gpointer data);
+static void on_message_view_destroyed (gpointer unused, GObject* where_the_object_was);
 static void on_message_buffer_flush (IAnjutaMessageView *view, const gchar *one_line, gpointer data);
 static void save_not_opened_files(FileBuffer *fb);
 static gboolean replace_in_not_opened_files(FileBuffer *fb, MatchInfo *mi, gchar *repl_str);
@@ -328,7 +327,6 @@ search_and_replace (void)
 		view = ianjuta_message_manager_get_view_by_name(msgman, name, NULL);
 		if (view == NULL)	
 		{
-			// FIXME: Put a nice icon here:
 			view = ianjuta_message_manager_add_view(msgman, name,
 													GTK_STOCK_FIND_AND_REPLACE, NULL);	
 			g_return_if_fail(view != NULL);
@@ -336,6 +334,7 @@ search_and_replace (void)
 			                  G_CALLBACK (on_message_buffer_flush), NULL);
 			g_signal_connect (G_OBJECT(view), "message_clicked",
 			                  G_CALLBACK (on_message_clicked), NULL);
+			g_object_weak_ref (G_OBJECT(view), on_message_view_destroyed, NULL);
 		}
 		else
 			ianjuta_message_view_clear(view, NULL);
@@ -369,7 +368,7 @@ search_and_replace (void)
 		else /* if (SE_FILE == se->type) */
 			fb = file_buffer_new_from_path(se->path, NULL, -1, 0);
 
-		if (fb)
+		if (fb && fb->buf)
 		{		
 			fb->pos = se->start_pos;
 			offset = 0;
@@ -451,8 +450,12 @@ search_and_replace (void)
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
-								fb->te = ianjuta_document_manager_goto_uri_line_mark
-									(sr->docman, fb->uri, mi->line, FALSE, NULL);
+							{
+								GFile* file = g_file_new_for_uri (fb->uri);
+								fb->te = ianjuta_document_manager_goto_file_line_mark
+									(sr->docman, file, mi->line, FALSE, NULL);
+								g_object_unref (file);
+							}
 							found_line = mi->line;
 						}
 						{
@@ -477,8 +480,12 @@ search_and_replace (void)
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
-								fb->te = ianjuta_document_manager_goto_uri_line_mark
-									(sr->docman, fb->uri, mi->line, FALSE, NULL);
+							{
+								GFile* file = g_file_new_for_uri (fb->uri);
+								fb->te = ianjuta_document_manager_goto_file_line_mark
+									(sr->docman, file, mi->line, FALSE, NULL);
+								g_object_unref (file);
+							}
 							found_line = mi->line;
 							}
 
@@ -586,29 +593,15 @@ search_and_replace (void)
 				if (SA_SELECT == s->action ||
 					((SA_REPLACE == s->action || SA_REPLACEALL == s->action) && interactive))
 					break;
-			} // while
-/* NO - leave the current position unchanged when marking-all
-			if (nb_results > 0)
-			{
-				switch (s->action)
-				{
-					case SA_HIGHLIGHT:
-					case SA_BOOKMARK:
-						ianjuta_editor_goto_line (fb->te, found_line, NULL);
-					default:
-						break;
-				}
 			}
-*/
-		if (save_file)
-		{
+			if (save_file)
+			{
 				save_not_opened_files (fb);
-			save_file = FALSE;
+				save_file = FALSE;
+			}
+			
 		}
-		
-			file_buffer_free (fb);
-		}  // if (fb)
-
+		file_buffer_free (fb);
 		g_free (se->path);
 		g_free (se);
 
@@ -675,6 +668,12 @@ write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se,
 	ianjuta_message_view_buffer_append (view, buf, NULL);
 }
 
+static void
+on_message_view_destroyed (gpointer unused, GObject* where_the_object_was)
+{
+	end_activity = TRUE;
+}
+
 static void
 on_message_buffer_flush (IAnjutaMessageView *view, const gchar *one_line,
 						 gpointer data)
@@ -688,7 +687,7 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 {
 	gchar *ptr, *ptr2;
 	gchar *path, *nline;
-	gchar *uri;
+	GFile* file;
 	gint line;
 		
 	if (!(ptr = g_strstr_len(message, strlen(message), ":")) )
@@ -701,9 +700,9 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 	nline = g_strndup(ptr, ptr2 - ptr);
 	line = atoi(nline);
 	
-	uri = gnome_vfs_get_uri_from_local_path (path);  
-	ianjuta_document_manager_goto_uri_line_mark (sr->docman, uri, line, TRUE, NULL);
-	g_free(uri);
+	file = g_file_new_for_path (path); 
+	ianjuta_document_manager_goto_file_line_mark (sr->docman, file, line, TRUE, NULL);
+	g_object_unref (file);
 	g_free(path);
 	g_free(nline);
 	return FALSE;
@@ -1354,21 +1353,6 @@ list_max_items(GList *list, guint nb_max)
 
 #define MAX_ITEMS_SEARCH_COMBO 16
 
-void
-search_toolbar_set_text(gchar *search_text)
-{
-	AnjutaUI *ui; 
-	GtkAction *action; 
-	
-	AnjutaShell* shell;
-	g_object_get(G_OBJECT(sr->docman), "shell", &shell, NULL);
-	
-	ui = anjuta_shell_get_ui (shell, NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupNavigation",
-								   "ActionEditSearchEntry");
-	egg_entry_action_set_text (EGG_ENTRY_ACTION(action), search_text);	
-}
-
 static void
 search_update_combos(void)
 {
@@ -1462,6 +1446,7 @@ search_update_dialog(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.no_limit);
 	widget = sr_get_gladewidget(ACTIONS_MAX)->widget;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget), s->expr.actions_max);
+	gtk_widget_set_sensitive (widget, !s->expr.no_limit);
 	
 	widget = sr_get_gladewidget(REPLACE_REGEX)->widget;	
 	gtk_widget_set_sensitive(widget, sr->search.expr.regex);
@@ -1616,7 +1601,8 @@ void
 on_search_regex_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 {
 	static GladeWidgetId dependent_widgets[] = {
-		GREEDY, IGNORE_CASE, WHOLE_WORD, WHOLE_LINE, WORD_START
+		WHOLE_WORD, WHOLE_LINE, WORD_START,
+		SEARCH_BACKWARD, SEARCH_FULL_BUFFER
 	};
 	int i;
 	GtkWidget *dircombo = sr_get_gladewidget(SEARCH_DIRECTION_COMBO)->widget;
@@ -1809,7 +1795,11 @@ on_search_button_stop_clicked(GtkButton *button, gpointer user_data)
 void
 on_search_button_next_clicked(GtkButton *button, gpointer user_data)
 {	
-	clear_pcre(); 	
+	if (sr->search.expr.regex_info)
+	{
+		g_regex_unref (sr->search.expr.regex_info);
+		sr->search.expr.regex_info = NULL;
+	}
 	search_replace_populate();
 
 	search_and_replace();
@@ -1832,7 +1822,7 @@ void search_replace_find_usage(const gchar *symbol)
 	sr->search.expr.word_start = FALSE;
 	sr->search.expr.no_limit = TRUE;
 	sr->search.expr.actions_max = G_MAXINT;
-	sr->search.expr.re = NULL;
+	sr->search.expr.regex_info = NULL;
 		
 	g_object_get(G_OBJECT(sr->docman), "shell", &shell, NULL);
 	
