@@ -121,7 +121,7 @@ FileBuffer *
 file_buffer_new_from_te (IAnjutaEditor *te)
 {
 	FileBuffer *fb;
-	gchar* uri;
+	GFile* file;
 	gchar* path;
 	
 	g_return_val_if_fail(te, NULL);
@@ -129,19 +129,21 @@ file_buffer_new_from_te (IAnjutaEditor *te)
 	fb->type = FB_EDITOR;
 	fb->te = te;
 	
-	uri = ianjuta_file_get_uri(IANJUTA_FILE(te), NULL);
-	path = gnome_vfs_get_local_path_from_uri(uri);
+	file = ianjuta_file_get_file(IANJUTA_FILE(te), NULL);
+	path = g_file_get_path (file);
 	if (path)
 	{
 		fb->path = tm_get_real_path(path);
 		g_free (path);
 	}
-	fb->uri = uri;
+	fb->uri = g_file_get_uri (file);
 	fb->len = ianjuta_editor_get_length(te, NULL);
 	fb->buf = ianjuta_editor_get_text_all (fb->te, NULL);
 	fb->pos = ianjuta_editor_get_offset(fb->te, NULL);
 	fb->line = ianjuta_editor_get_lineno(fb->te, NULL);
 	
+	g_object_unref (file);
+	
 	return fb;
 }
 
@@ -155,6 +157,7 @@ file_buffer_new_from_path (const char *path, const char *buf, int len, int pos)
 	IAnjutaEditor *te;
 	IAnjutaDocument* doc;
 	char *real_path;
+	GFile* file;
 	char *uri;
 	int i;
 	int lineno;
@@ -163,9 +166,11 @@ file_buffer_new_from_path (const char *path, const char *buf, int len, int pos)
 	real_path = tm_get_real_path(path);
 	
 	/* There might be an already open TextEditor with this path */
-	uri = gnome_vfs_get_uri_from_local_path (real_path);
-	doc = ianjuta_document_manager_find_document_with_uri (sr->docman,
-														 uri, NULL);
+	file = g_file_new_for_path (real_path);
+	uri = g_file_get_uri (file);
+	doc = ianjuta_document_manager_find_document_with_file (sr->docman,
+														 file, NULL);
+	g_object_unref (file);
 
 	if (doc && IANJUTA_IS_EDITOR (doc))
 	{
@@ -504,7 +509,7 @@ get_next_match(FileBuffer *fb, SearchDirection direction, SearchExpression *s)
 		gboolean found;
 		gint match_len;
 
-		match_len = strlen (s->search_str);
+		match_len = g_utf8_strlen (s->search_str, -1);
 		if (match_len == 0)
 			return NULL;
 
@@ -598,7 +603,10 @@ get_next_match(FileBuffer *fb, SearchDirection direction, SearchExpression *s)
 						break;
 					}
 					else
+					{
+						g_free (current_key);
 						current = g_utf8_next_char (current);
+					}
 				}
 				g_free (search_key);
 			}
@@ -606,15 +614,10 @@ get_next_match(FileBuffer *fb, SearchDirection direction, SearchExpression *s)
 		if (found)
 		{
 			mi = g_new0 (MatchInfo, 1);	//better to abort than silently fail to report match ?
-//			mi = g_try_new0 (MatchInfo, 1);
-//			if (mi)
-//			{
-				mi->pos = fb->pos;
-				mi->len = match_len;
-				mi->line = file_buffer_line_from_pos (fb, fb->pos);
-//			}
-//			else
-//				WARN USER ABOUT MEMORY ERROR
+			mi->pos = fb->pos;
+			mi->len = match_len;
+			mi->line = file_buffer_line_from_pos (fb, fb->pos);
+			
 			if (direction == SD_BACKWARD)
 				fb->pos -= match_len;
 			else
