@@ -33,7 +33,6 @@
 
 #include <gtk/gtk.h>
 
-#include "anjuta-document.h"
 #include "sourceview.h"
 #include <gtksourceview/gtksourceview.h>
 
@@ -74,7 +73,7 @@ struct _AnjutaViewClass
 {
 	GtkSourceViewClass parent_class;
 	
-	void (* char_added)  		(AnjutaDocument    *document,
+	void (* char_added)  		(GtkTextBuffer    *document,
 								 gint position,
 								 gchar character);
 };
@@ -94,13 +93,6 @@ void		 anjuta_view_select_all		(AnjutaView       *view);
 
 void		 anjuta_view_scroll_to_cursor 	(AnjutaView       *view);
 
-void 		 anjuta_view_set_colors 		(AnjutaView       *view, 
-						 gboolean         def,
-						 GdkColor        *backgroud, 
-						 GdkColor        *text,
-						 GdkColor        *selection, 
-						 GdkColor        *sel_text);
-
 void 		 anjuta_view_set_font		(AnjutaView       *view,
 						 gboolean         def,
 						 const gchar     *font_name);
