@@ -15,16 +15,18 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <gdl/gdl-icons.h>
 #include <libanjuta/resources.h>
 #include "an_symbol_info.h"
+#include <gio/gio.h>
+
+#define ICON_SIZE 16
 
 static AnjutaSymbolInfo* symbol_info_dup (const AnjutaSymbolInfo *from);
 static void symbol_info_free (AnjutaSymbolInfo *sfile);
@@ -252,7 +254,6 @@ anjuta_symbol_info_get_root_type (SVNodeType type)
 	}
 }
 
-static GdlIcons *icon_set = NULL;
 static GdkPixbuf **sv_symbol_pixbufs = NULL;
 
 #define CREATE_SV_ICON(N, F) \
@@ -267,40 +268,42 @@ sv_load_symbol_pixbufs (void)
 
 	if (sv_symbol_pixbufs)
 		return;
-
-	if (icon_set == NULL)
-		icon_set = gdl_icons_new (16);
-
 	sv_symbol_pixbufs = g_new (GdkPixbuf *, sv_max_t + 1);
 
-	CREATE_SV_ICON (sv_none_t,              "Icons.16x16.Literal");
-	CREATE_SV_ICON (sv_namespace_t,         "Icons.16x16.NameSpace");
-	CREATE_SV_ICON (sv_class_t,             "Icons.16x16.Class");
-	CREATE_SV_ICON (sv_struct_t,            "Icons.16x16.ProtectedStruct");
-	CREATE_SV_ICON (sv_union_t,             "Icons.16x16.PrivateStruct");
-	CREATE_SV_ICON (sv_typedef_t,           "Icons.16x16.Reference");
-	CREATE_SV_ICON (sv_function_t,          "Icons.16x16.Method");
-	CREATE_SV_ICON (sv_variable_t,          "Icons.16x16.Literal");
-	CREATE_SV_ICON (sv_enumerator_t,        "Icons.16x16.Enum");
-	CREATE_SV_ICON (sv_macro_t,             "Icons.16x16.Field");
-	CREATE_SV_ICON (sv_private_func_t,      "Icons.16x16.PrivateMethod");
-	CREATE_SV_ICON (sv_private_var_t,       "Icons.16x16.PrivateProperty");
-	CREATE_SV_ICON (sv_protected_func_t,    "Icons.16x16.ProtectedMethod");
-	CREATE_SV_ICON (sv_protected_var_t,     "Icons.16x16.ProtectedProperty");
-	CREATE_SV_ICON (sv_public_func_t,       "Icons.16x16.InternalMethod");
-	CREATE_SV_ICON (sv_public_var_t,        "Icons.16x16.InternalProperty");
+	CREATE_SV_ICON (sv_none_t,              "element-literal-16.png");
+	CREATE_SV_ICON (sv_namespace_t,         "element-namespace-16.png");
+	CREATE_SV_ICON (sv_class_t,             "element-class-16.png");
+	CREATE_SV_ICON (sv_struct_t,            "element-structure-16.png");
+	CREATE_SV_ICON (sv_union_t,             "element-structure-16.png");
+	CREATE_SV_ICON (sv_typedef_t,           "element-literal-16.png");
+	CREATE_SV_ICON (sv_function_t,          "element-method-16.png");
+	CREATE_SV_ICON (sv_variable_t,          "element-literal-16.png");
+	CREATE_SV_ICON (sv_enumerator_t,        "element-enumeration-16.png");
+	CREATE_SV_ICON (sv_macro_t,             "element-event-16.png");
+	CREATE_SV_ICON (sv_private_func_t,      "element-method-16.png");
+	CREATE_SV_ICON (sv_private_var_t,       "element-literal-16.png");
+	CREATE_SV_ICON (sv_protected_func_t,    "element-method-16.png");
+	CREATE_SV_ICON (sv_protected_var_t,     "element-literal-16.png");
+	CREATE_SV_ICON (sv_public_func_t,       "element-method-16.png");
+	CREATE_SV_ICON (sv_public_var_t,        "element-literal-16.png");
 	
-	sv_symbol_pixbufs[sv_cfolder_t] = gdl_icons_get_mime_icon (icon_set,
-							    "application/directory-normal");
-	sv_symbol_pixbufs[sv_ofolder_t] = gdl_icons_get_mime_icon (icon_set,
-							    "application/directory-normal");
+	sv_symbol_pixbufs[sv_cfolder_t] = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+																GTK_STOCK_DIRECTORY,
+																ICON_SIZE,
+																GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+																NULL);
+	sv_symbol_pixbufs[sv_ofolder_t] = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+																GTK_STOCK_DIRECTORY,
+																ICON_SIZE,
+																GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+																NULL);
 	sv_symbol_pixbufs[sv_max_t] = NULL;
 }
 
 /*-----------------------------------------------------------------------------
  * return the pixbufs. It will initialize pixbufs first if they weren't before
  */
-GdkPixbuf*
+const GdkPixbuf*
 anjuta_symbol_info_get_pixbuf  (SVNodeType node_type)
 {
 	if (!sv_symbol_pixbufs)
