@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include <config.h>
@@ -28,16 +28,17 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-launcher.h>
-#include <libanjuta/interfaces/ianjuta-message-manager.h>
+#include <libanjuta/anjuta-utils.h>
 
 #include "an_symbol_prefs.h"
 #include "tm_tagmanager.h"
 
 #define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-symbol-browser-plugin.glade"
-#define ICON_FILE "anjuta-symbol-browser-plugin.png"
-#define LOCAL_TAGS_DIR ".anjuta/tags"
-#define SYSTEM_TAGS_CACHE ".anjuta/system-tags.cache"
+#define ICON_FILE "anjuta-symbol-browser-plugin-48.png"
+#define LOCAL_TAGS_SUBDIR "tags/"
+#define SYSTEM_TAGS_CACHE "system-tags.cache"
 #define SYMBOL_BROWSER_TAGS "symbol.browser.tags"
+#define CREATE_GLOBAL_TAGS PACKAGE_DATA_DIR"/scripts/create_global_tags.sh"
 
 enum
 {
@@ -47,14 +48,12 @@ enum
 	N_COLUMNS
 };
 
-static SymbolBrowserPlugin* symbol_browser_plugin = NULL;
-
 static void 
 update_system_tags (GList *tags_files)
 {
 	gchar *output_file;
 	
-	output_file = g_build_filename (g_get_home_dir (), SYSTEM_TAGS_CACHE, NULL);
+	output_file = anjuta_util_get_user_cache_file_path (SYSTEM_TAGS_CACHE, NULL);
 	
 	DEBUG_PRINT ("Recreating system tags cache: %s", output_file);
 	
@@ -75,7 +74,7 @@ update_system_tags_only_add (const gchar *tag_file)
 	GList *tags_files;
 	gchar *output_file;
 	
-	output_file = g_build_filename (g_get_home_dir (), SYSTEM_TAGS_CACHE, NULL);
+	output_file = anjuta_util_get_user_cache_file_path (SYSTEM_TAGS_CACHE, NULL);
 	
 	DEBUG_PRINT ("Recreating system tags cache: %s", output_file);
 	
@@ -172,7 +171,7 @@ create_store (AnjutaPreferences *prefs)
 	store = gtk_list_store_new (N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_STRING,
 								G_TYPE_STRING);
 	
-	local_tags_dir = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
+	local_tags_dir = anjuta_util_get_user_cache_file_path (LOCAL_TAGS_SUBDIR, NULL);
 	tags_dirs = g_list_prepend (tags_dirs, local_tags_dir);
 	
 	/* Load the tags files */
@@ -358,10 +357,13 @@ static void
 refresh_tags_list (SymbolBrowserPlugin *plugin)
 {
 	GtkListStore *new_tags_store;
-	new_tags_store = create_store (plugin->prefs);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (plugin->pref_tree_view),
-							 GTK_TREE_MODEL (new_tags_store));
-	g_object_unref (new_tags_store);
+	if (plugin->pref_tree_view)
+	{
+		new_tags_store = create_store (plugin->prefs);
+		gtk_tree_view_set_model (GTK_TREE_VIEW (plugin->pref_tree_view),
+								 GTK_TREE_MODEL (new_tags_store));
+		g_object_unref (new_tags_store);
+	}
 }
 
 static void
@@ -374,10 +376,6 @@ on_create_tags_clicked (GtkButton *widget, SymbolBrowserPlugin *plugin)
 	AnjutaPreferences *pref;
 	GladeXML *gxml;
 	
-	/* Make sure program anjuta-tags can be found */
-	if (!anjuta_util_prog_is_installed ("anjuta-tags", TRUE))
-		return;
-	
 	pref = plugin->prefs;
 	gxml = glade_xml_new (GLADE_FILE, "create.symbol.tags.dialog", NULL);
 	
@@ -440,10 +438,14 @@ on_create_tags_clicked (GtkButton *widget, SymbolBrowserPlugin *plugin)
 		argv = g_new0 (gchar*, argc);
 		
 		argv[0] = g_strdup ("anjuta-tags");
-		tmp = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, name, NULL);
-		argv[1] = g_strconcat (tmp, ".anjutatags", NULL);
-		g_free (tmp);
-		
+
+		{
+			gchar *tmp = NULL;
+			tmp = anjuta_util_get_user_cache_file_path ("tags", name, NULL);
+			argv[1] = g_strconcat (tmp, ".anjutatags", NULL);
+			g_free (tmp);
+		}
+
 		argc = 2;
 		if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter))
 		{
@@ -476,19 +478,16 @@ on_create_tags_clicked (GtkButton *widget, SymbolBrowserPlugin *plugin)
 		}
 		
 		/* Create local tags directory */
-		tmp = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
-		if ((pid = fork()) == 0)
-		{
-			execlp ("mkdir", "mkdir", "-p", tmp, NULL);
-			perror ("Could not execute mkdir");
-		}
-		waitpid (pid, NULL, 0);
+
+		tmp = anjuta_util_get_user_cache_file_path (LOCAL_TAGS_SUBDIR, NULL);
+
 		g_free (tmp);
 		
 		/* Execute anjuta-tags to create tags for the given files */
 		if ((pid = fork()) == 0)
 		{
-			execvp ("anjuta-tags", argv);
+			execvp (g_build_filename (PACKAGE_LIB_DIR,
+									  "anjuta-tags", NULL), argv);
 			perror ("Could not execute anjuta-tags");
 		}
 		waitpid (pid, NULL, 0);
@@ -540,27 +539,20 @@ on_add_tags_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 		gchar *tmp;
 		pid_t pid;
 		
-		/* Create local tags directory */
-		tmp = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
-		if ((pid = fork()) == 0)
-		{
-			execlp ("mkdir", "mkdir", "-p", tmp, NULL);
-			perror ("Could not execute mkdir");
-		}
-		waitpid (pid, NULL, 0);
-		g_free (tmp);
-		
 		uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (fileselection));
 		
 		node = uris;
 		while (node)
 		{
-			gchar *dest, *src, *basename;
+			gchar *dest, *src;
 			
 			src = node->data;
-			basename = g_path_get_basename (src);
-			dest = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, basename, NULL);
-			g_free (basename);
+			{
+				gchar *basename;
+				basename = g_path_get_basename (src);
+				dest = anjuta_util_get_user_cache_file_path ("tags", basename, NULL);
+				g_free (basename);
+			}
 			
 			/* Copy the tags file in local tags directory */
 			GnomeVFSURI* source_uri = gnome_vfs_uri_new(src);
@@ -614,8 +606,7 @@ on_remove_tags_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 		if (tags_filename)
 		{
 			gchar *file_path, *path;
-			path = g_build_filename (g_get_home_dir(), LOCAL_TAGS_DIR,
-									 tags_filename, NULL);
+			path = anjuta_util_get_user_cache_file_path ("tags", tags_filename, NULL);
 			file_path = g_strconcat (path, ".anjutatags.gz", NULL);
 			
 			if (!g_file_test (file_path, G_FILE_TEST_EXISTS))
@@ -641,68 +632,115 @@ on_remove_tags_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 
 static void
 on_message (AnjutaLauncher *launcher,
-					   AnjutaLauncherOutputType output_type,
-					   const gchar * mesg, gpointer user_data)
+			AnjutaLauncherOutputType output_type,
+			const gchar * mesg, gpointer user_data)
 {
-	SymbolBrowserPlugin* plugin = (SymbolBrowserPlugin*) user_data;
-	if (plugin->mesg_view)
-		ianjuta_message_view_append (plugin->mesg_view, IANJUTA_MESSAGE_VIEW_TYPE_INFO,
-			 mesg, "", NULL);
+	AnjutaStatus *status;
+	gchar **lines, **line;
+	SymbolBrowserPlugin* plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (user_data);
+	
+	lines = g_strsplit (mesg, "\n", -1);
+	if (!lines)
+		return;
+	
+	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
+	
+	line = lines;
+	while (*line)
+	{
+		gint packages_count;
+		gchar *pos;
+		
+		if (sscanf (*line, "Scanning %d packages", &packages_count) == 1)
+			anjuta_status_progress_add_ticks (status, packages_count + 1);
+		else if ((pos = strstr (*line, ".anjutatags.gz")))
+		{
+			const gchar *package_name;
+		
+			/* Get the name of the package */
+			*pos = '\0';
+			package_name = g_strrstr (*line, "/");
+			if (package_name)
+			{
+				gchar *status_mesg;
+				package_name++;
+				status_mesg = g_strdup_printf (_("Scanning package: %s"),
+											   package_name);
+				anjuta_status_progress_tick (status, NULL, status_mesg);
+				g_free (status_mesg);
+			}
+			else
+				anjuta_status_progress_tick (status, NULL, *line);
+		}
+		line++;
+	}
+	g_strfreev (lines);
 }
 
 static void
-refresh_list (AnjutaLauncher *launcher, gint child_pid, gint status,
-				   gulong time_taken, SymbolBrowserPlugin *plugin)
+on_system_tags_update_finished (AnjutaLauncher *launcher, gint child_pid,
+								gint status, gulong time_taken,
+								SymbolBrowserPlugin *plugin)
 {
+	AnjutaStatus *statusbar;
+	GList *enabled_paths = NULL;
+	gchar *all_tags_path;
+	gchar **tags_paths, **tags_path;
+	
+	all_tags_path = anjuta_preferences_get (plugin->prefs,
+											SYMBOL_BROWSER_TAGS);
+	if (all_tags_path)
+	{
+		tags_paths = g_strsplit (all_tags_path, ":", -1);
+		tags_path = tags_paths;
+		while (*tags_path)
+		{
+			enabled_paths = g_list_prepend (enabled_paths,
+											g_strdup (*tags_path));
+			tags_path++;
+		}
+		g_free (all_tags_path);
+		g_strfreev (tags_paths);
+		enabled_paths = g_list_reverse (enabled_paths);
+	}
+	
+	/* Refresh the list */
 	refresh_tags_list(plugin);
-}
-
-static void
-on_mesg_view_destroy(SymbolBrowserPlugin* plugin, gpointer destroyed_view)
-{
-	plugin->mesg_view = NULL;
+	
+	/* Regenerate system-tags.cache */
+	if (enabled_paths)
+	{
+		update_system_tags (enabled_paths);
+		g_list_foreach (enabled_paths, (GFunc)g_free, NULL);
+		g_list_free (enabled_paths);
+	}
+	
+	g_object_unref (plugin->launcher);
+	plugin->launcher = NULL;
+	statusbar = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
+	anjuta_status_progress_tick (statusbar, NULL,
+								 _("Completed system tags generation"));
 }
 
 static void 
-on_update_global_clicked(GtkWidget *button, SymbolBrowserPlugin *plugin)
+on_update_global_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 {
 	gchar* tmp;
 	gint pid;
-	AnjutaLauncher* launcher;
-	IAnjutaMessageManager* mesg_manager;
 
+	if (plugin->launcher)
+		return; /* Already running */
+	
 	/* Create local tags directory */	
-	tmp = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
-	if ((pid = fork()) == 0)
-	{
-		execlp ("mkdir", "mkdir", "-p", tmp, NULL);
-		perror ("Could not execute mkdir");
-	}
-	waitpid (pid, NULL, 0);
+	tmp = anjuta_util_get_user_cache_file_path (LOCAL_TAGS_SUBDIR,NULL);
 	g_free (tmp);
-
-	/* Make sure program anjuta-tags can be found */
-	if (!anjuta_util_prog_is_installed ("create_global_tags.sh", TRUE))
-		return;
 	
-	mesg_manager = anjuta_shell_get_interface 
-		(ANJUTA_PLUGIN (plugin)->shell,	IAnjutaMessageManager, NULL);
-	plugin->mesg_view = 
-	    ianjuta_message_manager_get_view_by_name(mesg_manager, _("CVS"), NULL);
-	if (!plugin->mesg_view)
-	{
-		plugin->mesg_view =
-		     ianjuta_message_manager_add_view (mesg_manager, _("Create global tags"), 
-											  "anjuta-symbol-browser-plugin.png", NULL);
-		g_object_weak_ref (G_OBJECT (plugin->mesg_view), 
-						  (GWeakNotify)on_mesg_view_destroy, plugin);
-	}
-	ianjuta_message_view_clear(plugin->mesg_view, NULL);
-	
-	launcher = anjuta_launcher_new ();
-	g_signal_connect (G_OBJECT (launcher), "child-exited",
-						  G_CALLBACK (refresh_list), plugin);
-	anjuta_launcher_execute (launcher, "create_global_tags.sh", on_message, plugin);
+	plugin->launcher = anjuta_launcher_new ();
+	g_signal_connect (G_OBJECT (plugin->launcher), "child-exited",
+					  G_CALLBACK (on_system_tags_update_finished), plugin);
+	anjuta_launcher_set_buffered_output (plugin->launcher, TRUE);
+	anjuta_launcher_execute (plugin->launcher, CREATE_GLOBAL_TAGS,
+							 on_message, plugin);
 }
 
 static GtkWidget *
@@ -715,7 +753,8 @@ prefs_page_init (SymbolBrowserPlugin *plugin)
 	AnjutaPreferences *pref = plugin->prefs;
 	GladeXML *gxml = glade_xml_new (GLADE_FILE, NULL, NULL);
 	
-	anjuta_preferences_add_page (pref, gxml, "Symbol Browser", ICON_FILE);
+	anjuta_preferences_add_page (pref, gxml, "Symbol Browser",
+								 _("Symbol Browser"),  ICON_FILE);
 	treeview = glade_xml_get_widget (gxml, "tags_treeview");
 	
 	store = create_store (pref);
@@ -760,8 +799,6 @@ prefs_page_init (SymbolBrowserPlugin *plugin)
 					  G_CALLBACK (on_update_global_clicked), plugin);
 	
 	
-	symbol_browser_plugin = plugin;
-	
 	g_object_unref (store);
 	g_object_unref (gxml);
 	return treeview;
@@ -772,29 +809,29 @@ on_gconf_notify_tags_list_changed (GConfClient *gclient, guint cnxn_id,
 								   GConfEntry *entry, gpointer user_data)
 {
 	GtkListStore *store;
-	SymbolBrowserPlugin *plugin = (SymbolBrowserPlugin*)user_data;
-	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (plugin->pref_tree_view)));
-	select_loaded_tags (store, plugin->prefs);
+	SymbolBrowserPlugin *plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (user_data);
+	
+	if (plugin->pref_tree_view)
+	{
+		store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (plugin->pref_tree_view)));
+		select_loaded_tags (store, plugin->prefs);
+	}
 }
 
 void
 symbol_browser_prefs_init (SymbolBrowserPlugin *plugin)
 {
 	guint notify_id;
-	static gboolean page_initialized = FALSE;
-	
-	if (!page_initialized)
-	{
-		plugin->pref_tree_view = prefs_page_init (plugin);
-		page_initialized = TRUE;
-	}
+	plugin->pref_tree_view = prefs_page_init (plugin);
+	g_object_add_weak_pointer (G_OBJECT (plugin->pref_tree_view),
+							   (gpointer)&plugin->pref_tree_view);
 	plugin->gconf_notify_ids = NULL;
 	notify_id = anjuta_preferences_notify_add (plugin->prefs,
 											   SYMBOL_BROWSER_TAGS,
 											   on_gconf_notify_tags_list_changed,
 											   plugin, NULL);
 	plugin->gconf_notify_ids = g_list_prepend (plugin->gconf_notify_ids,
-											   (gpointer)notify_id);
+											   GUINT_TO_POINTER (notify_id));
 }
 
 void
@@ -804,16 +841,35 @@ symbol_browser_prefs_finalize (SymbolBrowserPlugin *plugin)
 	node = plugin->gconf_notify_ids;
 	while (node)
 	{
-		anjuta_preferences_notify_remove (plugin->prefs, (guint)node->data);
+		anjuta_preferences_notify_remove (plugin->prefs,
+										  GPOINTER_TO_UINT (node->data));
 		node = g_list_next (node);
 	}
 	g_list_free (plugin->gconf_notify_ids);
 	plugin->gconf_notify_ids = NULL;
+	
+	anjuta_preferences_remove_page(plugin->prefs, _("Symbol Browser"));
 }
 
-
-gboolean symbol_browser_prefs_create_global_tags(gpointer unused)
+static gboolean
+symbol_browser_prefs_create_global_tags (gpointer user_data)
 {
-	on_update_global_clicked(NULL, symbol_browser_plugin);
+	SymbolBrowserPlugin *plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (user_data);
+	on_update_global_clicked (NULL, plugin);
 	return FALSE; /* Stop g_idle */
 }
+
+void
+symbol_browser_load_global_tags (gpointer plugin)
+{
+	gchar *system_tags_path;
+	/* Load gloabal tags on gtk idle */
+	system_tags_path = anjuta_util_get_user_cache_file_path (SYSTEM_TAGS_CACHE,NULL);
+	if (!tm_workspace_load_global_tags (system_tags_path))
+	{
+		g_message ("Added idle loop to create global tags");
+		g_idle_add((GSourceFunc) symbol_browser_prefs_create_global_tags, 
+				   plugin);
+	}
+	g_free (system_tags_path);
+}
