@@ -22,6 +22,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-utils.h>
 #include <libanjuta/interfaces/ianjuta-help.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
@@ -32,7 +33,6 @@
 #include <libanjuta/interfaces/ianjuta-markable.h>
 #include <libanjuta/interfaces/ianjuta-symbol-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
-#include <libegg/menu/egg-combo-action.h>
 
 #include <tm_tagmanager.h>
 #include "an_symbol_view.h"
@@ -46,6 +46,7 @@
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-symbol-browser-plugin.ui"
 #define PREFS_GLADE PACKAGE_DATA_DIR"/glade/anjuta-symbol-browser-plugin.glade"
 #define ICON_FILE "anjuta-symbol-browser-plugin-48.png"
+#define SYMBOL_BROWSER_TAGS "symbol.browser.tags"
 
 #define TIMEOUT_INTERVAL_SYMBOLS_UPDATE		10000
 
@@ -80,7 +81,7 @@ register_stock_icons (AnjutaPlugin *plugin)
 static void
 goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 {
-	gchar *uri;
+	GFile* file;
 	IAnjutaDocumentManager *docman;
 	
 	g_return_if_fail (filename != NULL);
@@ -89,9 +90,9 @@ goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 	docman = anjuta_shell_get_interface (plugin->shell, IAnjutaDocumentManager,
 										 NULL);
 		
-	uri = gnome_vfs_get_uri_from_local_path (filename);
-	ianjuta_document_manager_goto_uri_line (docman, uri, lineno, NULL);
-	g_free (uri);
+	file = g_file_new_for_path (filename);
+	ianjuta_document_manager_goto_file_line (docman, file, lineno, NULL);
+	g_object_unref (file);
 }
 
 static void
@@ -351,6 +352,8 @@ on_project_element_removed (IAnjutaProjectManager *pm, const gchar *uri,
 	}
 }
 
+#define LOCAL_TAGS_SUBDIR "tags/"
+
 // add a new project
 static void
 project_root_added (AnjutaPlugin *plugin, const gchar *name,
@@ -394,7 +397,35 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 					  G_CALLBACK (on_project_element_added), sv_plugin);
 	g_signal_connect (G_OBJECT (pm), "element_removed",
 					  G_CALLBACK (on_project_element_removed), sv_plugin);
-}
+	/* Load from project */
+	if (anjuta_preferences_get_int (sv_plugin->prefs,
+											"symbol_browser.tags_auto_load"))
+	{		
+		gchar* pref_symbols = anjuta_preferences_get (sv_plugin->prefs, SYMBOL_BROWSER_TAGS);
+		gchar* dirname = anjuta_util_get_user_cache_file_path (LOCAL_TAGS_SUBDIR,NULL);
+		GList* packages = ianjuta_project_manager_get_packages (pm, NULL);
+		GList* node;
+		GString* str = g_string_new (pref_symbols);
+		g_free (pref_symbols);
+		for (node = packages; node != NULL; node = g_list_next (node))
+		{
+			gchar* pathname = g_build_filename (dirname, node->data, NULL);
+			if (!strstr (str->str, pathname))
+			{
+				if (str->len)
+					g_string_append_c (str, ':');
+				g_string_append (str, pathname);
+				g_string_append (str, ".anjutatags.gz");
+			}
+			g_free (pathname);
+		}
+		g_list_foreach (packages, (GFunc) g_free, NULL);
+		g_list_free (packages);
+		anjuta_preferences_set (sv_plugin->prefs, SYMBOL_BROWSER_TAGS, str->str);
+		g_string_free (str, TRUE);
+		g_free (dirname);
+	}
+}	   
 
 static void
 project_root_removed (AnjutaPlugin *plugin, const gchar *name,
@@ -420,10 +451,12 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 										  sv_plugin);
 	
 	/* clear anjuta_symbol_search side */
-	anjuta_symbol_search_clear(ANJUTA_SYMBOL_SEARCH(sv_plugin->ss));
+	if (sv_plugin->ss)
+		anjuta_symbol_search_clear(ANJUTA_SYMBOL_SEARCH(sv_plugin->ss));
 
 	/* clear glist's sfiles */
-	anjuta_symbol_view_clear (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree));
+	if (sv_plugin->sv_tree)
+		anjuta_symbol_view_clear (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree));
 
 	g_free (sv_plugin->project_root_uri);
 	sv_plugin->project_root_uri = NULL;
@@ -543,17 +576,6 @@ goto_tree_iter (SymbolBrowserPlugin *sv_plugin, GtkTreeIter *iter)
 	}
 }
 
-static void
-on_symbol_selected (GtkAction *action, SymbolBrowserPlugin *sv_plugin)
-{
-	GtkTreeIter iter;
-	
-	if (egg_combo_action_get_active_iter (EGG_COMBO_ACTION (action), &iter))
-	{
-		goto_tree_iter (sv_plugin, &iter);
-	}
-}
-
 static void
 on_local_treeview_row_activated (GtkTreeView *view, GtkTreePath *arg1,
 								 GtkTreeViewColumn *arg2,
@@ -604,29 +626,41 @@ on_editor_destroy (SymbolBrowserPlugin *sv_plugin, IAnjutaEditor *editor)
 											   uri);
 	}
 	g_hash_table_remove (sv_plugin->editor_connected, G_OBJECT (editor));
+	
+	/* was it the last file loaded? */
+	if (g_hash_table_size (sv_plugin->editor_connected) <= 0)
+	{
+		DEBUG_PRINT ("displaying nothing...");
+		gtk_tree_view_set_model (GTK_TREE_VIEW (sv_plugin->sl_tree),
+									 NULL);
+	}	
 }
 
 static void
-on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
+on_editor_saved (IAnjutaEditor *editor, GFile* file,
 				 SymbolBrowserPlugin *sv_plugin)
 {
 	const gchar *old_uri;
 	gboolean tags_update;
 	GtkTreeModel *file_symbol_model;
-	GtkAction *action;
 	AnjutaUI *ui;
 	
 	/* FIXME: Do this only if automatic tags update is enabled */
 	/* tags_update =
 		anjuta_preferences_get_int (te->preferences, AUTOMATIC_TAGS_UPDATE);
 	*/
+	
+	if (!file)
+		return;
+	
 	tags_update = TRUE;
 	if (tags_update)
 	{
 		gchar *local_filename;
+		gchar *saved_uri = g_file_get_uri (file);
 		
 		/* Verify that it's local file */
-		local_filename = gnome_vfs_get_local_path_from_uri (saved_uri);
+		local_filename = g_file_get_path (file);
 		g_return_if_fail (local_filename != NULL);
 		g_free (local_filename);
 		
@@ -644,8 +678,6 @@ on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
 		
 		/* Update File symbol view */
 		ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (sv_plugin)->shell, NULL);
-		action = anjuta_ui_get_action (ui, "ActionGroupSymbolNavigation",
-									   "ActionGotoSymbol");
 		
 		
 		file_symbol_model =
@@ -653,18 +685,12 @@ on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
 		g_object_set_data (G_OBJECT (editor), "tm_file",
 						   g_object_get_data (G_OBJECT (file_symbol_model),
 											  "tm_file"));
-		/* Set toolbar version */
-		egg_combo_action_set_model (EGG_COMBO_ACTION (action), file_symbol_model);
 		/* Set local view version */
 		gtk_tree_view_set_model (GTK_TREE_VIEW (sv_plugin->sl_tree),
 								 file_symbol_model);
 		sv_plugin->locals_line_number = 0;
 		on_editor_update_ui (editor, sv_plugin);
-		
-		if (gtk_tree_model_iter_n_children (file_symbol_model, NULL) > 0)
-			g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
-		else
-			g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
+		g_free (saved_uri);
 
 #if 0
 		/* FIXME: Re-hilite all editors on tags update */
@@ -714,18 +740,20 @@ update_editor_symbol_model (SymbolBrowserPlugin *sv_plugin)
 {
 	AnjutaUI *ui;
 	gchar *uri;
+	GFile* file;
 	GObject *editor = sv_plugin->current_editor;
 	
 	if (!editor)
 		return;
 	
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (sv_plugin)->shell, NULL);
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
-	if (uri)
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	if (file)
 	{
+		uri = g_file_get_uri (file);
+		g_object_unref (file);
 		gchar *local_filename;
 		GtkTreeModel *file_symbol_model;
-		GtkAction *action;
 		
 		/* Verify that it's local file */
 		local_filename = gnome_vfs_get_local_path_from_uri (uri);
@@ -733,8 +761,6 @@ update_editor_symbol_model (SymbolBrowserPlugin *sv_plugin)
 		g_free (local_filename);
 		
 		anjuta_symbol_view_workspace_add_file (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree), uri);
-		action = anjuta_ui_get_action (ui, "ActionGroupSymbolNavigation",
-									   "ActionGotoSymbol");
 		g_free (uri);
 		
 		file_symbol_model =
@@ -744,19 +770,12 @@ update_editor_symbol_model (SymbolBrowserPlugin *sv_plugin)
 			g_object_set_data (G_OBJECT (editor), "tm_file",
 						   g_object_get_data (G_OBJECT (file_symbol_model),
 											  "tm_file"));
-			/* Set toolbar version */
-			egg_combo_action_set_model (EGG_COMBO_ACTION (action), file_symbol_model);
 			
 			/* Set local view version */
 			gtk_tree_view_set_model (GTK_TREE_VIEW (sv_plugin->sl_tree),
 									 file_symbol_model);
 			sv_plugin->locals_line_number = 0;
 			on_editor_update_ui (IANJUTA_EDITOR (editor), sv_plugin);
-			
-			if (gtk_tree_model_iter_n_children (file_symbol_model, NULL) > 0)
-				g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
-			else
-				g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
 		}
 	}
 }
@@ -770,11 +789,7 @@ iter_matches (SymbolBrowserPlugin *sv_plugin, GtkTreeIter* iter,
 	if (line == lineno)
 	{
 		GtkTreePath* path = gtk_tree_model_get_path (model, iter);
-		GtkAction* action = anjuta_ui_get_action (sv_plugin->ui, 
-												  "ActionGroupSymbolNavigation",
-												  "ActionGotoSymbol");
 		
-		egg_combo_action_set_active_iter (EGG_COMBO_ACTION (action), iter);
 		gtk_tree_view_set_cursor (GTK_TREE_VIEW (sv_plugin->sl_tree), path, NULL,
 								 FALSE);
 		gtk_tree_path_free (path);
@@ -796,7 +811,10 @@ on_editor_update_ui (IAnjutaEditor *editor, SymbolBrowserPlugin *sv_plugin)
 	if (sv_plugin->locals_line_number == lineno)
 		return;
 	sv_plugin->locals_line_number = lineno;
-	
+
+	if (model == NULL);
+		return;
+
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
 	while (!found && lineno >= 0)
@@ -820,6 +838,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	gchar *uri;
 	GObject *editor;
 	SymbolBrowserPlugin *sv_plugin;
+	GFile* file;
 	
 	editor = g_value_get_object (value);
 	
@@ -838,7 +857,10 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	
 	update_editor_symbol_model (sv_plugin);
 	
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	uri = file ? g_file_get_uri (file) : NULL;
+	if (file)
+		g_object_unref (file);
 	if (g_hash_table_lookup (sv_plugin->editor_connected, editor) == NULL)
 	{
 		g_object_weak_ref (G_OBJECT (editor),
@@ -869,15 +891,11 @@ value_removed_current_editor (AnjutaPlugin *plugin,
 {
 	AnjutaUI *ui;
 	SymbolBrowserPlugin *sv_plugin;
-	GtkAction *action;
 
 	/* let's remove the timeout for symbols refresh */
 	
 	sv_plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (plugin);
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupSymbolNavigation",
-								   "ActionGotoSymbol");
-	g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
 	sv_plugin->current_editor = NULL;
 }
 
@@ -885,7 +903,6 @@ static gboolean
 activate_plugin (AnjutaPlugin *plugin)
 {
 	GtkActionGroup *group;
-	GtkAction *action;
 	SymbolBrowserPlugin *sv_plugin;
 	
 	DEBUG_PRINT ("SymbolBrowserPlugin: Activating Symbol Manager plugin...");
@@ -983,19 +1000,7 @@ activate_plugin (AnjutaPlugin *plugin)
 											G_N_ELEMENTS (popup_actions),
 											GETTEXT_PACKAGE, FALSE, plugin);
 	group = gtk_action_group_new ("ActionGroupSymbolNavigation");
-
-	/* create a new combobox in style of libegg... */
-	action = g_object_new (EGG_TYPE_COMBO_ACTION,
-						   "name", "ActionGotoSymbol",
-						   "label", _("Goto symbol"),
-						   "tooltip", _("Select the symbol to go"),
-						   "stock_id", GTK_STOCK_JUMP_TO,
-							NULL);
-
-	g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
-	g_signal_connect (action, "activate",
-					  G_CALLBACK (on_symbol_selected), sv_plugin);
-	gtk_action_group_add_action (group, action);
+	
 	anjuta_ui_add_action_group (sv_plugin->ui, "ActionGroupSymbolNavigation",
 								N_("Symbol navigations"), group, FALSE);
 	sv_plugin->action_group_nav = group;
@@ -1012,11 +1017,11 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	/* set up project directory watch */
 	sv_plugin->root_watch_id = anjuta_plugin_add_watch (plugin,
-									"project_root_uri",
+									IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 									project_root_added,
 									project_root_removed, NULL);
 	sv_plugin->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	return TRUE;
@@ -1028,6 +1033,8 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	SymbolBrowserPlugin *sv_plugin;
 	sv_plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (plugin);
 	
+	DEBUG_PRINT ("SymbolBrowserPlugin: Dectivating Symbol Manager plugin...");
+	
 	/* Ensure all editor cached info are released */
 	if (sv_plugin->editor_connected)
 	{
@@ -1038,6 +1045,15 @@ deactivate_plugin (AnjutaPlugin *plugin)
 		g_hash_table_destroy (sv_plugin->editor_connected);
 		sv_plugin->editor_connected = NULL;
 	}
+
+	/* clear anjuta_symbol_search side */
+	if (sv_plugin->ss)
+		anjuta_symbol_search_clear(ANJUTA_SYMBOL_SEARCH(sv_plugin->ss));
+
+	/* clear glist's sfiles */
+	if (sv_plugin->sv_tree)
+		anjuta_symbol_view_clear (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree));
+	
 	/* Remove watches */
 	anjuta_plugin_remove_watch (plugin, sv_plugin->root_watch_id, FALSE);
 	anjuta_plugin_remove_watch (plugin, sv_plugin->editor_watch_id, TRUE);
@@ -1090,14 +1106,14 @@ dispose (GObject *obj)
 										   (gpointer)&sv_plugin->ss);
 
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
 finalize (GObject *obj)
 {
 	/* SymbolBrowserPlugin *plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (obj); */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -1133,9 +1149,14 @@ symbol_browser_plugin_class_init (SymbolBrowserPluginClass *klass)
 static IAnjutaIterable*
 isymbol_manager_search (IAnjutaSymbolManager *sm,
 						IAnjutaSymbolType match_types,
+						gboolean include_types,
+						IAnjutaSymbolField info_fields,
 						const gchar *match_name,
 						gboolean partial_name_match,
-						gboolean global_search,
+						gboolean global_symbols_search,
+						gboolean global_tags_search, /* unused */
+						gint results_limit, /* unused */
+						gint results_offset, /* unused */
 						GError **err)
 {
 	const GPtrArray *tags_array;
@@ -1148,25 +1169,29 @@ isymbol_manager_search (IAnjutaSymbolManager *sm,
 		name = NULL;
 	
 	tags_array = tm_workspace_find (name, match_types, NULL,
-									partial_name_match, global_search);
+									partial_name_match, global_symbols_search);
 	if (tags_array && tags_array->len)
 	{
 		iter = anjuta_symbol_iter_new (tags_array);
 		return IANJUTA_ITERABLE (iter);
 	}
-	return NULL;
+	return NULL;	
 }
 
 static IAnjutaIterable*
 isymbol_manager_get_members (IAnjutaSymbolManager *sm,
-							 const gchar *symbol_name,
+							 const IAnjutaSymbol *symbol, 
+							 IAnjutaSymbolField info_fields,
 							 gboolean global_search,
 							 GError **err)
 {
 	const GPtrArray *tags_array;
 	AnjutaSymbolIter *iter = NULL;
+	AnjutaSymbol *s;
 	
-	tags_array = tm_workspace_find_scope_members (NULL, symbol_name,
+	s = ANJUTA_SYMBOL (symbol);
+	
+	tags_array = tm_workspace_find_scope_members (NULL, anjuta_symbol_get_name (s),
 												  global_search, TRUE);
 												  
 	
@@ -1179,14 +1204,18 @@ isymbol_manager_get_members (IAnjutaSymbolManager *sm,
 }
 
 static IAnjutaIterable*
-isymbol_manager_get_parents (IAnjutaSymbolManager *sm,
-							 const gchar *symbol_name,
+isymbol_manager_get_class_parents (IAnjutaSymbolManager *sm,
+							 const IAnjutaSymbol *symbol,
+							 IAnjutaSymbolField info_fields,
 							 GError **err)
 {
 	const GPtrArray *tags_array;
 	AnjutaSymbolIter *iter = NULL;
+	AnjutaSymbol *s;
 	
-	tags_array = tm_workspace_get_parents (symbol_name);
+	s = ANJUTA_SYMBOL (symbol);
+	
+	tags_array = tm_workspace_get_parents (anjuta_symbol_get_name (s));
 	if (tags_array && tags_array->len)
 	{
 		iter = anjuta_symbol_iter_new (tags_array);
@@ -1195,12 +1224,59 @@ isymbol_manager_get_parents (IAnjutaSymbolManager *sm,
 	return NULL;
 }
 
+static IAnjutaIterable*
+isymbol_manager_get_scope (IAnjutaSymbolManager *sm,
+						   const gchar* filename,  
+						   gulong line,  
+						   IAnjutaSymbolField info_fields, 
+						   GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_scope (): not implemented");
+	return NULL;
+}
+
+static IAnjutaIterable*
+isymbol_manager_get_parent_scope (IAnjutaSymbolManager *sm,
+								  const IAnjutaSymbol *symbol, 
+								  const gchar *filename, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_parent_scope (): not implemented");
+	return NULL;	
+}
+
+
+static IAnjutaIterable*
+isymbol_manager_get_symbol_more_info (IAnjutaSymbolManager *sm,
+								  const IAnjutaSymbol *symbol, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_symbol_more_info (): not implemented");
+	return NULL;
+}
+
+static IAnjutaSymbol*
+isymbol_manager_get_symbol_by_id (IAnjutaSymbolManager *sm,
+								  gint symbol_id, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_symbol_by_id  (): not implemented");
+	return NULL;	
+}
+
 static void
 isymbol_manager_iface_init (IAnjutaSymbolManagerIface *iface)
 {
 	iface->search = isymbol_manager_search;
 	iface->get_members = isymbol_manager_get_members;
-	iface->get_parents = isymbol_manager_get_parents;
+	iface->get_class_parents = isymbol_manager_get_class_parents;
+	iface->get_scope = isymbol_manager_get_scope;
+	iface->get_parent_scope = isymbol_manager_get_parent_scope;
+	iface->get_symbol_more_info = isymbol_manager_get_symbol_more_info;
+	iface->get_symbol_by_id = isymbol_manager_get_symbol_by_id;
 }
 
 static void
