@@ -15,26 +15,33 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
+#ifdef ENABLE_NLS
+#  include <locale.h>
+#endif
+
 #include <sys/stat.h>
 
-#include <gnome.h>
+#include <libgnome/gnome-program.h>
 #include <gtk/gtkwindow.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <libanjuta/resources.h>
-#include <libanjuta/plugins.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 
 #include "anjuta.h"
 #include "bacon-message-connection.h"
 
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
+
 #define ANJUTA_PIXMAP_SPLASH_SCREEN       "anjuta_splash.png"
 
 /* App */
@@ -50,42 +57,58 @@ static gint line_position = 0;
 static GList *file_list = NULL;
 static gboolean no_splash = 0;
 static gboolean no_client = 0;
+static gboolean no_session = 0;
+static gboolean no_files = 0;
 static gboolean proper_shutdown = 0;
 static gchar *anjuta_geometry = NULL;
+static gchar **anjuta_filenames = NULL;
 
-/* The static variables used in the poptTable.*/
-/* anjuta's option table */
-static struct 
-poptOption anjuta_options[] = {
+static const GOptionEntry anjuta_options[] = {
 	{
-	 	NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE,
-	 	0, NULL, NULL
-	},
-	{
-		"geometry", 'g', POPT_ARG_STRING,
-		&anjuta_geometry, 0,
+		"geometry", 'g', 0, G_OPTION_ARG_STRING,
+		&anjuta_geometry,
 		N_("Specify the size and location of the main window"),
+		/* This is the format you can specify the size andposition
+		 * of the window on command line */
 		N_("WIDTHxHEIGHT+XOFF+YOFF")
 	},
 	{
-		"no-splash", 's', POPT_ARG_NONE,
-		&no_splash, 0,
+		"no-splash", 's', 0, G_OPTION_ARG_NONE,
+		&no_splash,
 		N_("Do not show the splashscreen"),
 		NULL
 	},
 	{
-		"no-client", 'c', POPT_ARG_NONE,
-		&no_client, 0,
+		"no-client", 'c', 0, G_OPTION_ARG_NONE,
+		&no_client,
 		N_("Start a new instance and do not open the file in a existing"),
 		NULL
 	},
 	{
-		"proper-shutdown", 'p', POPT_ARG_NONE,
-		&proper_shutdown, 0,
+		"no-session", 'n', 0, G_OPTION_ARG_NONE,
+		&no_session,
+		N_("Do not open last session on startup"),
+		NULL
+	},
+	{
+		"no-files", 'f', 0, G_OPTION_ARG_NONE,
+		&no_files,
+		N_("Do not open last project and files on startup"),
+		NULL
+	},
+	{
+		"proper-shutdown", 'p', 0, G_OPTION_ARG_NONE,
+		&proper_shutdown,
 		N_("Shutdown anjuta properly releasing all resources (for debugging)"),
 		NULL
 	},
-	POPT_AUTOHELP {NULL}
+	{
+		G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
+		&anjuta_filenames,
+		NULL,
+		NULL
+	},
+	{NULL}
 };
 
 static gchar*
@@ -111,24 +134,13 @@ get_real_path (const gchar *file_name)
 }
 
 static void
-get_command_line_args (GnomeProgram *program)
+get_command_line_args ()
 {
-	poptContext ctx;
-	gchar **args;
-	gint i;
-	GValue value = { 0, };
-
-	g_value_init (&value, G_TYPE_POINTER);
-	g_object_get_property (G_OBJECT (program),
-						   GNOME_PARAM_POPT_CONTEXT, &value);
-	ctx = g_value_get_pointer (&value);
-	g_value_unset (&value);
-
-	args = (char**) poptGetArgs(ctx);
-	if (args) 
-		for (i = 0; args[i]; i++) 
-			file_list = g_list_append (file_list,
-										  get_real_path (args[i]));
+	int i;
+	if (anjuta_filenames) 
+		for (i = 0; anjuta_filenames[i]; i++) 
+ 			file_list = g_list_append (file_list,
+										  get_real_path (anjuta_filenames[i]));
 }
 
 static GdkDisplay *
@@ -156,8 +168,7 @@ display_open_if_needed (const gchar *name)
 
 /* serverside */
 static void
-on_message_received (const char *message,
-		     gpointer    data)
+on_message_received (const char *message, gpointer    data)
 {
 	gchar **commands;
 	gchar **params;
@@ -166,6 +177,7 @@ on_message_received (const char *message,
 	gint i;
 	GdkDisplay *display;
 	GdkScreen *screen;
+	GList* file;
 
 	g_return_if_fail (message != NULL);
 
@@ -184,6 +196,7 @@ on_message_received (const char *message,
 	g_strfreev (params);
 
 	/* body */
+	gtk_window_present (GTK_WINDOW (app));
 	i = 1;
 	while (commands[i])
 	{
@@ -220,15 +233,16 @@ on_message_received (const char *message,
 
 	/* execute the commands */
 
-	while (file_list != NULL)
+	for (file = file_list; file != NULL; file = g_list_next (file))
 	{
-		IAnjutaFileLoader* file =
+		IAnjutaFileLoader* loader =
 			anjuta_shell_get_interface(ANJUTA_SHELL(app), IAnjutaFileLoader, NULL);
-		gchar* uri = g_strdup_printf("%s:%d", (gchar*) file_list->data, line_position);
-		
-		ianjuta_file_loader_load(file, file_list->data, FALSE, NULL);
-		g_free(uri);
-		file_list = g_list_next(file_list);
+		GFile* gfile = g_file_new_for_commandline_arg(file->data);
+		if (gfile)
+		{
+			ianjuta_file_loader_load(loader, gfile, FALSE, NULL);
+			g_object_unref (gfile);
+		}
 	}
 
 	/* free the file list and reset to default */
@@ -295,39 +309,51 @@ int
 main (int argc, char *argv[])
 {
 	GnomeProgram *program;
+	GOptionContext *context;
 	gchar *data_dir;
-	GList *plugins_dirs = NULL;
 	char *im_file;
 	
+	context = g_option_context_new (_("- Integrated Development Environment"));
 #ifdef ENABLE_NLS
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+	g_option_context_add_main_entries (context, anjuta_options, PACKAGE);	
+#else
+	g_option_context_add_main_entries (context, anjuta_options, NULL);
 #endif
 	
 	data_dir = g_strdup (PACKAGE_DATA_DIR);
 	data_dir[strlen (data_dir) - strlen (PACKAGE) - 1] = '\0';
 	
+    /* Initialize threads, if possible */
+#ifdef G_THREADS_ENABLED    
+    if (!g_thread_supported()) g_thread_init(NULL);
+#else
+#warning "Some plugins won't work without thread support"
+#endif
+    
 	/* Initialize gnome program */
+	g_option_context_parse (context, &argc, &argv, NULL);
 	program = gnome_program_init (PACKAGE, VERSION,
 								  LIBGNOMEUI_MODULE, argc, argv,
-								  GNOME_PARAM_POPT_TABLE, anjuta_options,
+								  GNOME_PARAM_GOPTION_CONTEXT, context,
 								  GNOME_PARAM_HUMAN_READABLE_NAME,
 								  _("Integrated Development Environment"),
 								  GNOME_PARAM_APP_DATADIR, data_dir,
-								  NULL);
+								  GNOME_PARAM_NONE);
 	g_free (data_dir);
 	
 	/* Get the command line files */
-	get_command_line_args (program);
+	get_command_line_args ();
 	
 	connection = bacon_message_connection_new ("anjuta");
 	
 	if (connection != NULL)
 	{
 		if (!bacon_message_connection_get_is_server (connection) &&
-			 no_client ==FALSE) 
+			 no_client == FALSE) 
 		{
 			DEBUG_PRINT("Client");
 			send_bacon_message ();
@@ -353,17 +379,14 @@ main (int argc, char *argv[])
 		g_warning ("Cannot create the 'anjuta' connection.");
 	
 	g_set_application_name (_("Anjuta"));
-	gtk_window_set_default_icon_name ("anjuta_icon");
+	gtk_window_set_default_icon_name ("anjuta");
 	gtk_window_set_auto_startup_notification(FALSE);
 
 	im_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_SPLASH_SCREEN);
 	
-	/* Initialize plugins */
-	plugins_dirs = g_list_prepend (plugins_dirs, PACKAGE_PLUGIN_DIR);
-	anjuta_plugins_init (plugins_dirs);
-	
-	app = anjuta_new (argv[0], file_list, no_splash, im_file,
-					  proper_shutdown, anjuta_geometry);
+	/* Initialize applicatoin */
+	app = anjuta_new (argv[0], file_list, no_splash, no_session, no_files,
+					  im_file, proper_shutdown, anjuta_geometry);
 	
 	g_free (im_file);
 	gtk_window_set_role (GTK_WINDOW (app), "anjuta-app");
@@ -373,7 +396,7 @@ main (int argc, char *argv[])
 	gtk_widget_show (GTK_WIDGET (app));
 	gtk_main();
 	
-	/* Finalize plugins system */
-	anjuta_plugins_finalize ();
+	gnome_vfs_shutdown();
+	
 	return 0;
 }
